@@ -9,7 +9,7 @@ use Types::Standard qw(Str);
 
 with 'Role::REST::Client';
 
-our $VERSION = "0.1.0";
+our $VERSION = "0.1.1";
 
 has api_url => (
 	isa => Str,
@@ -96,7 +96,8 @@ __END__
 
 =head1 NAME
 
-Webservice::Swapi - A Perl module to interface with the L<Star Wars API|http://swapi.co> webservice.
+Webservice::Swapi - A Perl module to interface with the Star Wars API
+(swapi.co) webservice.
 
 =head1 SYNOPSIS
 
@@ -118,10 +119,7 @@ Webservice::Swapi - A Perl module to interface with the L<Star Wars API|http://s
 
 =head1 DESCRIPTION
 
-Webservice::Swapi is a Perl client helper library for the L<Star Wars API|http://swapi.co>.
-
-=head1 Docker Setup
-
+Webservice::Swapi is a Perl client helper library for the Star Wars API (swapi.co).
 
 =head1 DEVELOPMENT
 
